# Brain Predictability Toolbox (BPt)

- The Brain Predictability toolbox (BPt) is a Python based Machine Learning library designed for working with Neuroimaging data. This library is particularly suited towards working with large neuroimaging datasets, where a large number of subjects with potentially multimodal data are avaliable.

- Please check out the project documentation at:
<https://bpt.readthedocs.io/en/latest/>

- For examples on how to use this library, please visit the Examples folder hosted on this github.

- This library is based on python and likely will require atleast some prior experience with python and machine learning. That said, if interested in a web-based GUI interface version of BPt (which uses this library in the background), please visit https://github.com/sahahn/BPt_app. 



### Install

The easiest way to install the latest stable release of BPt is via pip, just run
``` 
pip install brain-pred-toolbox 
```

You can also clone this respository and and install it locally to get the latest version.
See: https://bpt.readthedocs.io/en/latest/install.html#pip-installation for more information.

### Changelog

See: https://bpt.readthedocs.io/en/latest/change_log.html